@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006  Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2006, 2007  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@ soundcard.initialise_external_midiplayer(....)
 soundard.play_wav_file = play_wav
 """
 import sys
-from track import Track, PercussionTrack
+from mpd.track import Track, PercussionTrack
 from soundcardexceptions import SoundInitException
 synth = None
 
