@@ -26,7 +26,7 @@ class Synth:
     def stop(self):
         pass
     def play_track(self, *tracks):
-        print "FakeSynth.play_track(%s)" % tracks
+        print "FakeSynth.play_track()"
         last = None
         for e in MidiEventStream(*tracks):
             if e[0] != last:
