@@ -1,5 +1,5 @@
-# GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006 Tom Cato Amundsen
+# GNU Solfege - free ear training software
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,18 +16,19 @@
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
 import sys, os, tempfile, signal
-import mfutils
 import textwrap
-from track import MidiEventStream
+from synth_common import SynthCommon
+from mpd.track import MidiEventStream
 
 def ms_win_kill(pid):
     import win32api
     handle = win32api.OpenProcess(1, 0, pid)
     return (0 != win32api.TerminateProcess(handle, 0))
 
-class MidiFileSynth:
+class MidiFileSynth(SynthCommon):
     NUM_CHANNELS = 16
     def __init__(self, cmd, verbose_init):
+        SynthCommon.__init__(self)
         self.m_type_major = "Midifile"
         self.m_cmd = cmd
         self.m_tmpfilename = tempfile.mkstemp(".mid")[1]
@@ -57,13 +58,18 @@ class MidiFileSynth:
             return " ".join((cmd, filename))
     def play_track(self, *tracks):
         self.play_midieventstream(MidiEventStream(*tracks))
+    def play_midieventstream(self, midieventstream):
+        if sys.platform == 'win32':
+            self._play_midieventstream_system(*midieventstream)
+        else:
+            self._play_midieventstream_fork_execl(*midieventstream)
     def _play_midieventstream_system(self, midieventstream):
-        self.create_midifile(midieventstream)
+        midieventstream.create_midifile(self.m_tmpfilename)
         os.system(self.join_cmd_and_filename(self.m_cmd, self.m_tmpfilename))
         # spawnl(os.P_DETACH, 'c:\\python20\\python', 'python', 'script.py')
         # #P_DETACH'ed can be killed
     def _play_midieventstream_fork_execl(self, midieventstream):
-        self.create_midifile(midieventstream)
+        midieventstream.create_midifile(self.m_tmpfilename)
         if not os.path.isfile(self.m_cmd.split()[0]):
             msg = _("""Failed to play music because the selected midi player program '%s' does not exist. You have to change the sound setup from the preferences window (Ctrl-F12).""") % self.m_cmd.split()[0]
             if self.error_report_cb:
@@ -90,35 +96,6 @@ class MidiFileSynth:
                 os._exit(-1)
         else:
             self.__child_pid = pid
-    def create_midifile(self, stream):
-        v = []
-        notelen = 0
-        v += mfutils.mf_tempo(60 * 4 / 4)
-        for e in stream:
-            if e[0] == stream.TEMPO:
-                v = v + mfutils.mf_tempo(e[1] * 4 / e[2])
-            elif e[0] == stream.NOTELEN_TIME:
-                notelen = e[1]
-            elif e[0] == stream.NOTE_ON:
-                v = v + mfutils.mf_note_on(int(96 * 4 * notelen), e[1], e[2], e[3])
-                notelen = 0
-            elif e[0] == stream.NOTE_OFF:
-                v = v + mfutils.mf_note_off(int(96 * 4 * notelen), e[1], e[2], e[3])
-                notelen = 0
-            elif e[0] == stream.SET_PATCH:
-                v = v + mfutils.mf_program_change(e[1], e[2])
-            elif e[0] == stream.BENDER:
-                print "FIXME todo: seq_bender for play_with_drvmidi"
-                #m.seq_bender(DEV, e[1], e[2])
-            else:
-                raise "Corrupt track error"
-        f = open(self.m_tmpfilename, "w")
-        mfutils.MThd(f)
-        f.write("MTrk")
-        mfutils.write_int32(f, len(v)+4)
-        v = v + mfutils.mf_end_of_track()
-        mfutils.write_vect(f, v)
-        f.close()
     def stop(self):
         if sys.platform != 'win32':
             if self.__child_pid:
@@ -132,8 +109,9 @@ class MidiFileSynth:
 def test():
     synth = MidiFileSynth("/usr/bin/timidity %s", True)
     sys.path.insert(0, ".")
-    import track
-    from rat import Rat
+    import mpd
+    from mpd.track import track
+    from mpd.rat import Rat
     import src.i18n
     src.i18n.setup(".")
     t1 = track.Track()
