@@ -21,11 +21,9 @@ import inputwidgets
 from specialwidgets import RandomTransposeDialog
 from exceptiondialog import ExceptionDialog
 import soundcard, mpd
-import dataparser
 
 import const, utils
 import random
-import os
 import locale
 import sys
 import traceback
@@ -88,11 +86,6 @@ class Teacher(cfg.ConfigUtils):
         Set the variable 'm_lessonfile' and
         parse the lesson file and save the statistics.
         """
-        if lessonfile is not None \
-                and lessonfile == self.m_lessonfile:
-            new_file = 0
-        else:
-            new_file = 1
         self.m_lessonfile = lessonfile
         self.parse_lessonfile()
         if self.m_P and self.m_statistics:
@@ -290,10 +283,8 @@ class RhythmAddOnClass:
                 count_in_notelen = self.m_P.header.count_in_notelen
             else:
                 count_in_notelen = "4"
-            for x in range(self.get_int("count_in")):
-                s = s + "d%s " % count_in_notelen
-        for k in self.m_question:
-            s = s + self.RHYTHMS[k] + " "
+            s = "d%s " % count_in_notelen * self.get_int("count_in")
+        s += " ".join([self.RHYTHMS[k] for k in self.m_question])
         return s
     def get_music_string(self):
         """
@@ -671,12 +662,13 @@ class IntervalGui(Gui):
             v = []
             for x in range(self.get_int('maximum_number_of_intervals')):
                 v.append('ask_for_intervals_%i' % x)
-        if i == 0:#new_widget_name == _("Buttons"):
+        if i == 0:
+            assert inputwidgets.inputwidget_names[i] == _("Buttons")
             self.g_input = inputwidgets.IntervalButtonsWidget(self.m_exname,
                   'intervals', self.click_on_interval, self.get_interval_input_list, v)
         else:
             self.g_input = inputwidgets.name_to_inputwidget(
-                                 inputwidgets.inputwidget_names[i], #new_widget_name,
+                                 inputwidgets.inputwidget_names[i],
                                  self.click_on_interval)
         self.practise_box.pack_start(self.g_input)
         self.practise_box.reorder_child(self.g_input, 1)
