@@ -78,14 +78,21 @@ True
 
 import re
 import codecs
-import os, os.path, sys
+import os, os.path
 import gethomedir
-import unittest
 
 section_re = re.compile("^\[([\w-]*?)\]")
 value_re = re.compile(  "^([\w-]*?)=(.*)")
 comment_re = re.compile("#.*")
 
+_blocked_watches = {}
+_watches = {}
+_watch_counter = {}
+_user_filename = None
+_app_defaults_filename = None
+_system_filename = None
+data = {}
+
 def split(key):
     return key.split("/")
 
@@ -411,24 +418,4 @@ class ConfigUtils(object):
         except SyntaxError:
             return []
 
-class Test_parse_file_into_dict(unittest.TestCase):
-    def test_fail_on_non_utf8(self):
-        d = {}
-        try:
-            parse_file_into_dict(d, "test-files/test1.cfg")
-        except UnicodeDecodeError, e:
-            self.assertRaises(NameError, lambda: data)
-    def test_parse_utf8(self):
-        d = {}
-        parse_file_into_dict(d, "test-files/test2.cfg")
-        self.assertEquals(d['sound']['i'], u'3')
-        self.assertEquals(d['sound']['f'], u'1.1')
-        self.assertEquals(d['sound']['s'], u'/home/Us\xe9r/bin/prog')
-        self.assert_(isinstance(d['sound']['s'], basestring))
-        self.assert_(isinstance(d['sound']['s'], unicode))
 
-if __name__ == '__main__':
-    import doctest, cfg
-    print doctest.testmod(cfg)
-    #import pdb; pdb.set_trace()
-    unittest.main()
