@@ -15,8 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import os
-
 import gtk
 import gu
 import mpd, mpd.musicdisplayer
@@ -24,8 +22,6 @@ import abstract, const, lessonfile
 from mpd.rat import Rat
 import soundcard
 import utils
-import configureoutput
-import dataparser
 
 class Teacher(abstract.Teacher):
     """
