@@ -159,6 +159,11 @@ class Teacher(abstract.Teacher):
         m.set_patch(instr_high)
         m.note(4, high_tone, instr_high_vel)
         soundcard.synth.play_track(m)
+    def start_practise(self):
+        self.m_custom_mode = bool(not self.m_P.header.intervals)
+        if self.m_P.header.intervals:
+            self.set_list('intervals', self.m_P.header.intervals)
+        self.set_bool('disable_unused_intervals', self.m_P.header.disable_unused_intervals)
 
 class Gui(abstract.IntervalGui):
     def __init__(self, teacher, window):
@@ -314,14 +319,11 @@ class Gui(abstract.IntervalGui):
         self.m_t.play_melodic()
         self.g_input.grab_focus_first_sensitive_button()
     def on_start_practise(self):
-        self.m_t.m_custom_mode = bool(not self.m_t.m_P.header.intervals)
-        if self.m_t.m_P.header.intervals:
-            self.set_list('intervals', self.m_t.m_P.header.intervals)
+        self.m_t.start_practise()
         if self.m_t.m_P.header.lesson_heading:
             self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
         else:
             self.set_lesson_heading(_("Identify the interval"))
-        self.set_bool('disable_unused_intervals', self.m_t.m_P.header.disable_unused_intervals)
         if self.m_t.m_custom_mode:
             self.g_ask_for_frame.show()
         else:
