@@ -254,7 +254,7 @@ class Gui(abstract.LessonbasedGui):
                     return
         except Exception, e:
             if not self.standard_exception_handler(e, __file__):
-                raise e
+                raise
     def on_left_click(self, button):
         if self.m_t.q_status == const.QSTATUS_NO:
             if self.m_t.m_app.m_test_mode:
@@ -284,7 +284,7 @@ class Gui(abstract.LessonbasedGui):
                     self.g_give_up.set_sensitive(True)
         except Exception, e:
             if not self.standard_excpetion_handler(e, __file__):
-                raise e
+                raise
     def new_question(self, widget=None):
         """
         The new button should be insensitive if we have no lesson file.
@@ -324,7 +324,7 @@ class Gui(abstract.LessonbasedGui):
             self.g_flashbar.flash(_("You have to select some questions to practise."))
         except Exception, e:
             if not self.standard_exception_handler(e, __file__, exception_cleanup):
-                raise e
+                raise
     def on_start_practise(self):
         self.m_t.m_custom_mode = self.get_bool('gui/expert_mode')
         for question in self.m_t.m_P.m_questions:
