@@ -15,10 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-if __name__ == '__main__':
-    import testsetup
 
-import unittest
 import glob
 import xrandom
 import uuid
@@ -126,6 +123,7 @@ keywords = (
     'singinterval',
     'melodicinterval',
     'harmonicinterval',
+    'example',
     'idtone',
     'twelvetone',
     'identifybpm',
@@ -1208,7 +1206,7 @@ def parse_lesson_file_header(filename):
     many lesson files.
     """
     r = re.compile("\\header\s{.*?}", re.MULTILINE|re.DOTALL)
-    s = file(filename, 'r').read()
+    s = open(filename, 'rU').read()
     m = r.search(s)
     p = dataparser.Dataparser(predef, lessonfile_functions)
     p.m_ignore_lookup_error = True
@@ -1223,7 +1221,7 @@ class LessonIdParser(object):
     """
     def __init__(self, filename):
         self.m_filename = filename
-        f = file(filename, 'r')
+        f = open(filename, 'rU')
         self.m_file_content = f.read()
         f.close()
     def has_header_block(self):
@@ -1241,7 +1239,7 @@ class LessonIdParser(object):
         Generate and add a new lesson_id for the file filename.
         """
         if self.has_lesson_id():
-            ofile = file(self.m_filename, 'w')
+            ofile = open(self.m_filename, 'w')
             m = re.search("lesson_id\s*=\s*\".+?\"", self.m_file_content)
             ofile.write(self.m_file_content[:m.start()])
             self.m_new_id = uuid.generate()
@@ -1263,7 +1261,7 @@ class LessonIdParser(object):
         self.m_new_id = uuid.generate()
         v.insert(i+1, "header { \n    lesson_id=\"%s\"\n}" % self.m_new_id)
         self.m_file_content = "\n".join(v)
-        ofile = file(self.m_filename, 'w')
+        ofile = open(self.m_filename, 'w')
         ofile.write(self.m_file_content)
         ofile.close()
     def add_lesson_id(self):
@@ -1274,7 +1272,7 @@ class LessonIdParser(object):
         if not self.has_header_block():
             self.add_header_block()
         else:
-            ofile = file(self.m_filename, 'w')
+            ofile = open(self.m_filename, 'w')
             m = re.search("^\s*header\s*{", self.m_file_content,
                             re.MULTILINE)
             if m:
@@ -1285,20 +1283,4 @@ class LessonIdParser(object):
                 ofile.write(self.m_file_content[m.end():])
             ofile.close()
 
-class TestParser(unittest.TestCase):
-    def test_bad_musictype(self):
-        s = 'question {\n' \
-            'music = music("c e g", "chor")\n' \
-            '}'
-        p = LessonfileCommon("<STRING>")
-        try:
-            p.parse_string(s)
-        except UnknownMusicType, e:
-            self.assertEquals(e.m_token[dataparser.TOKEN_STRING], "chor")
-            self.assertEquals('(line 1): question {\n'
-                              '(line 2): music = music("c e g", "chor")\n'
-                              '                                 ^',
-                              e.m_nonwrapped_text)
 
-if __name__ == '__main__':
-    unittest.main()
