@@ -17,8 +17,6 @@
 
 # Lesson file related GUI code.
 
-if __name__ == '__main__':
-    import testsetup
 
 import gtk
 import locale
