@@ -22,7 +22,6 @@ import abstract, const
 import statistics, statisticsviewer
 import soundcard, utils, mpd
 import lessonfile
-import random
 
 class Teacher(abstract.MelodicIntervalTeacher):
     def __init__(self, exname, app):
@@ -64,7 +63,26 @@ class Teacher(abstract.MelodicIntervalTeacher):
             if self.m_app.m_test_mode:
                 self.maybe_auto_new_question()
             self.q_status = const.QSTATUS_WRONG
-
+    def start_practise(self):
+        # First, we have to empty the cfg database because we will
+        # copy the values from the lesson header.
+        for i in range(self.get_int('maximum_number_of_intervals')):
+            self.set_list('ask_for_intervals_%i' % i, [])
+        # If ask_for_intervals_0 is not set, then we run in custom_mode
+        # where the user configure the exercise on her own.
+        if 'ask_for_intervals_0' in self.m_P.header:
+            self.set_bool('disable_unused_intervals', self.m_P.header.disable_unused_intervals)
+            for i in range(self.get_int('maximum_number_of_intervals')):
+                if 'ask_for_intervals_%i' % i in self.m_P.header:
+                    self.set_list('ask_for_intervals_%i' % i,
+                      self.m_P.header['ask_for_intervals_%i' % i])
+                else:
+                    break
+            self.set_int('number_of_intervals', i)
+        else:
+            self.set_list('ask_for_intervals_0', [])
+            self.set_int('number_of_intervals', 1)
+        self.m_custom_mode = bool(not self.m_P.header.ask_for_intervals_0)
 
 class Gui(abstract.IntervalGui):
     def __init__(self, teacher, window):
@@ -226,27 +244,11 @@ class Gui(abstract.IntervalGui):
         elif ret == Teacher.ERR_PICKY:
             self.g_flashbar.flash(_("You have to solve this question first."))
     def on_start_practise(self):
-        # First, we have to empty the cfg database because we will
-        # copy the values from the lesson header.
-        for i in range(self.get_int('maximum_number_of_intervals')):
-            self.set_list('ask_for_intervals_%i' % i, [])
-        # If ask_for_intervals_0 is not set, then we run in custom_mode
-        # where the user configure the exercise on her own.
-        if 'ask_for_intervals_0' in self.m_t.m_P.header:
-            self.set_bool('disable_unused_intervals', self.m_t.m_P.header.disable_unused_intervals)
-            for i in range(self.get_int('maximum_number_of_intervals')):
-                if 'ask_for_intervals_%i' % i in self.m_t.m_P.header:
-                    self.set_list('ask_for_intervals_%i' % i,
-                      self.m_t.m_P.header['ask_for_intervals_%i' % i])
-                else:
-                    break
-            self.set_int('number_of_intervals', i)
+        self.m_t.start_practise()
         if self.m_t.m_P.header.lesson_heading:
             self.set_lesson_heading(self.m_t.m_P.header.lesson_heading)
         else:
             self.set_lesson_heading(_("Identify the interval"))
-        self.m_t.m_custom_mode = bool(
-            not self.m_t.m_P.header.ask_for_intervals_0)
         if self.m_t.m_custom_mode:
             self.g_mici.show()
         else:
