@@ -15,7 +15,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin ST, Fifth Floor, Boston, MA  02110-1301  USA
 
-import pango
 import gtk
 import gobject
 import random
@@ -26,7 +25,6 @@ import gu
 import mpd
 import utils
 import const
-import cfg
 
 class Teacher(abstract.Teacher):
     def __init__(self, exname, app):
@@ -113,7 +111,7 @@ class Teacher(abstract.Teacher):
             n = self.m_P.header.interval_number[0]
         try:
             i = mpd.Interval("%s%s" % (q, n))
-        except mpd.interval.InvalidIntervalnameException, e:
+        except mpd.interval.InvalidIntervalnameException:
             return False
         return i == self.m_interval
     def forget_answers(self):
