@@ -29,9 +29,9 @@ class AbstractQuestionNameTable(gtk.Table, cfg.ConfigUtils):
         gtk.Table.__init__(self)
         cfg.ConfigUtils.__init__(self, exname)
         self._ignore_watch = 0
-        # will be defined in subclasses. Set to none to please pychecker.
-        self.ask_for_names_changed = None
         self.add_watch('ask_for_names', self.ask_for_names_changed)
+    def ask_for_names_changed(self):
+        pass
     def initialize(self, num, dir):
         self.m_num = num
         self.m_dir = dir
