@@ -230,7 +230,7 @@ class TrainingSetDialog(gtk.Window):
             assert isinstance(sub, gtk.MenuItem)
             if sub.get_submenu():
                 self._menu_hide_stuff(sub.get_submenu())
-                if not [c for c in sub.get_submenu().get_children() if c.props.visible]:
+                if not [c for c in sub.get_submenu().get_children() if c.get_property('visible')]:
                     sub.hide()
     def init_empty_file(self):
         self.m_changed = False
@@ -309,7 +309,7 @@ class TrainingSetDialog(gtk.Window):
         m.destroy()
         if r == gtk.RESPONSE_CLOSE:
             self.destroy()
-        elif r == gtk.RESPONSE_CANCEL:
+        elif r in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
             return
         else:
             assert r == gtk.RESPONSE_OK
@@ -364,7 +364,7 @@ class TrainingSetDialog(gtk.Window):
         """
         Return True if the file was saved, False if not.
         """
-        dialog = gtk.FileChooserDialog(_("Save File As"), self,
+        dialog = gtk.FileChooserDialog(_("Save As..."), self,
             gtk.FILE_CHOOSER_ACTION_SAVE,
             (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
              gtk.STOCK_OK, gtk.RESPONSE_OK))
@@ -454,7 +454,7 @@ class TrainingSetDialog(gtk.Window):
         dialog.vbox.pack_start(label, False, False)
         while 1:
             res = dialog.run()
-            if res == gtk.RESPONSE_CANCEL:
+            if res in (gtk.RESPONSE_CANCEL, gtk.RESPONSE_DELETE_EVENT):
                 dialog.destroy()
                 return
             if os.listdir(dialog.get_filename()):
