@@ -73,7 +73,7 @@ class DisplaytestWindow(gtk.Window):
     def on_play_first(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
-        tr = mpd.music_to_track(t, 100, soundcard.rat.Rat(0, 1), soundcard.rat.Rat(1, 8))
+        tr = mpd.music_to_track(t, 100, mpd.Rat(0, 1), mpd.Rat(1, 8))
         soundcard.synth.play_track(tr)
 
 
